@@ -3,7 +3,7 @@ package Prty;
 use strict;
 use warnings;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 =encoding utf8
 
@@ -14,7 +14,7 @@ Prty - Class library in Perl
 =head1 DESCRIPTION
 
 Diese Klassenbibliothek enthält anwendungsunabhängige Klassen,
-die ich im Rahmen meiner Perl-Projekte entwickelt habe. Die Klassen
+die ich im Rahmen von Perl-Projekten entwickelt habe. Die Klassen
 sind nach einheitlichen Prinzipien konzipiert. Die Bibliothek
 befindet sich unter kontinuierlicher Weiterentwicklung.
 
@@ -152,6 +152,10 @@ L<Prty::Duration> - Rechnen und Konvertieren von Zeiträumen
 
 =item *
 
+L<Prty::Epoch> - Ein Zeitpunkt
+
+=item *
+
 L<Prty::ExampleCode> - Führe Beispielcode aus
 
 =item *
@@ -384,6 +388,10 @@ L<Prty::Progress> - Berechne Fortschrittsinformation
 
 =item *
 
+L<Prty::Record> - Verarbeitung von Text-Records
+
+=item *
+
 L<Prty::Rsync> - Aufruf von rsync von Perl aus
 
 =item *
@@ -524,7 +532,7 @@ L<Prty::TextFile::Line> - Zeile einer Textdatei
 
 =item *
 
-L<Prty::Time> - Ein Zeitpunkt
+L<Prty::Time> - Klasse zur Repräsentation von Datum und Uhrzeit
 
 =item *
 
@@ -558,7 +566,7 @@ L<Prty::Unindent> - Entferne Einrückung von "Here Document" oder String-Literal
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
