@@ -3,8 +3,9 @@ use base qw/Prty::Object/;
 
 use strict;
 use warnings;
+use utf8;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 use Prty::Object;
 use Prty::Perl;
@@ -614,9 +615,111 @@ sub median {
 
 # -----------------------------------------------------------------------------
 
+=head2 Dump/Restore
+
+=head3 dump() - Erzeuge einzeilige, externe Repräsentation
+
+=head4 Synopsis
+
+    $str = $arr->dump;
+    $str = $arr->dump($colSep);
+    $str = $class->dump(\@arr);
+    $str = $class->dump(\@arr,$colSep);
+
+=head4 Description
+
+Liefere eine einzeilige, externe Repräsentation für Array $arr bzw. @arr
+im Format
+
+    elem0|elem1|...|elemN
+
+Die Array-Elemente werden durch "|" (bzw. $colSep) getrennt. In den
+Elementen werden folgende Wandlungen vorgenommen:
+
+    undef    -> '' (undef wird zu Leerstring)
+    \        -> \\ (Backslash wird verdoppelt)
+    $colSep  -> \!
+    LF       -> \n
+    CR       -> \r
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub dump {
+    my $arr = ref $_[0]? CORE::shift: CORE::splice @_,0,2;
+    my $colSep = CORE::shift // '|';
+
+    my $regex = qr/\Q$colSep/;
+
+    my $str;
+    for (@$arr) {
+        if (!defined) {
+            $_ = '';
+        }
+
+        s/\\/\\\\/g;
+        s/$regex/\\!/g;
+        s/\n/\\n/g;
+        s/\r/\\r/g;
+
+        if (defined $str) {
+            $str .= $colSep;
+        }
+        $str .= $_;
+    }
+
+    return defined $str? $str: '';
+}
+
+# -----------------------------------------------------------------------------
+
+=head3 restore() - Wandele einzeilige, externe Repräsentation in Array
+
+=head4 Synopsis
+
+    $arr = $class->restore($str);
+    $arr = $class->restore($str,$colSep);
+
+=head4 Description
+
+Wandele einzeilige, externe Array-Repräsentation (siehe Methode dump())
+in ein Array-Objekt und liefere dieses zurück.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub restore {
+    my $class = CORE::shift;
+    my $str = CORE::shift;
+    my $colSep = CORE::shift // '|';
+
+    my $f = sub {
+        return '\\' if $_[0] eq '\\';
+        return $colSep if $_[0] eq '!';
+        return "\n" if $_[0] eq 'n';
+        return "\r" if $_[0] eq 'r';
+
+        $class->throw(
+            q{ARR-00001: Inkorrekte Array-Repräsentation},
+            EscapeSequence=>"\\$_[0]",
+        );
+    };
+
+    my @arr = split /\Q$colSep/,$str,-1;
+    for (@arr) {
+        s/\\(.)/$f->($1,$colSep)/ge;
+    }
+
+    return bless \@arr,$class;
+}
+
+# -----------------------------------------------------------------------------
+
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
