@@ -4,7 +4,7 @@ use base qw/Prty::Object/;
 use strict;
 use warnings;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 # -----------------------------------------------------------------------------
 
@@ -20,7 +20,7 @@ L<Prty::Object>
 
 =head1 DESCRIPTION
 
-Ein Objekt der Klasse ist Träger von Formatinformation über eine
+Ein Objekt der Klasse ist Träger von Formatinformation über einer
 Menge von Werten, die tabellarisch dargestellt werden sollen,
 z.B. in einer Text- oder HTML-Tabelle.
 
@@ -101,14 +101,23 @@ sub asFixedWidthString {
     if (!defined($value) || $value eq '') {
         return ' ' x $width;
     }
-    elsif ($type eq 's' || $type eq 't') {
-        $value = sprintf '%-*s', $self->[1],$value;
+
+    if (($type eq 'd' || $type eq 'f') && $value =~ /[^-\d.]/) {
+        # Einen nicht-numerischen Wert in einer numerischen Kolumne
+        # (z.B. Überschrift) formatieren wir als String
+
+        $type = 's';
+        $width = $width+$scale;
+    }
+
+    if ($type eq 's' || $type eq 't') {
+        $value = sprintf '%-*s',$width,$value;
     }
     elsif ($type eq 'd') {
-        $value = sprintf '%*d',$self->[1],$value;
+        $value = sprintf '%*d',$width,$value;
     }
     elsif ($type eq 'f') {
-        $value = sprintf '%*.*f',$self->[1],$self->[2],$value;
+        $value = sprintf '%*.*f',$width,$scale,$value;
     }
     else {
         $self->throw(
@@ -182,7 +191,7 @@ sub htmlAlign {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
