@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 use Prty::Option;
 use DBI ();
@@ -183,7 +183,7 @@ sub new {
 
     if (!$handle) {
         if ($dbms eq 'oracle') {
-            $dbh->{'LongReadLen'} = 1024*1024; # 1MB
+            $dbh->{'LongReadLen'} = 3*1024*1024; # 3MB
             if ($utf8) {
                 $dbh->{'ora_charset'} = 'AL32UTF8';
             }
@@ -484,7 +484,7 @@ sub sql {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
