@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 # -----------------------------------------------------------------------------
 
@@ -181,6 +181,14 @@ sub bindTypes {
                     push @$arr,undef;
                 }
             }
+            elsif ($type eq 'NUMBER') {
+                if ($dbms eq 'oracle') {
+                    push @$arr,{ora_type=>DBD::Oracle::ORA_NUMBER()};
+                }
+                else {
+                    push @$arr,undef;
+                }
+            }
             elsif ($type eq 'XML') {
                 if ($dbms eq 'oracle') {
                     push @$arr,{ora_type=>DBD::Oracle::ORA_XMLTYPE()};
@@ -376,7 +384,7 @@ sub fetch {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
