@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 use Prty::Sql;
 use Prty::Object;
@@ -15,10 +15,10 @@ use Prty::Database::Api;
 use Prty::Hash;
 use POSIX ();
 use Prty::FileHandle;
+use Prty::Array;
 use Prty::String;
 use Prty::Database::Cursor;
 use Time::HiRes ();
-use Prty::Array;
 
 # -----------------------------------------------------------------------------
 
@@ -978,6 +978,92 @@ sub endProgressLog {
 
 # -----------------------------------------------------------------------------
 
+=head2 Export/Import
+
+=head3 exportTable() - Exportiere Tabelle
+
+=head4 Synopsis
+
+    $db->exportTable($table,$file);
+
+=head4 Description
+
+Exportiere die Daten der Tabelle $table in Datei $file.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub exportTable {
+    my ($self,$table,$file) = @_;
+
+    my $colSep = '|';
+    my $cur = $self->select($table,
+        -cursor=>1,
+        -raw=>1,
+    );
+    my $titleA = $cur->titles;
+
+    my $fh = Prty::FileHandle->new('>',$file);
+    $fh->setEncoding('utf-8');
+    $fh->print(Prty::Array->dump($titleA,$colSep),"\n");
+    while (my $rowA = $cur->fetch) {
+        $fh->print(Prty::Array->dump($rowA,$colSep),"\n");
+    }
+    $fh->close;
+    $cur->close;
+
+    return;
+}
+
+# -----------------------------------------------------------------------------
+
+=head3 importTable() - Importiere Tabelle
+
+=head4 Synopsis
+
+    $db->importTable($table,$file);
+
+=head4 Description
+
+Importiere die Daten aus Datei $file in Tabelle $table.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub importTable {
+    my ($self,$table,$file) = @_;
+
+    my $colSep = '|';
+    my $fh = Prty::FileHandle->new('<',$file);
+    $fh->setEncoding('utf-8');
+
+    my $line = scalar <$fh>;
+    chomp $line;
+    my $titleA = Prty::Array->restore($line,$colSep);
+
+    my @placeholders;
+    for (@$titleA) {
+        push @placeholders,\(my $s = '?');
+    }
+    my $stmt = $self->stmt->insert($table,$titleA,\@placeholders);
+    my $cur = $self->sql($stmt);
+
+    while (my $line = <$fh>) {
+        chomp $line;
+        $cur->bind(Prty::Array->restore($line,$colSep));
+    }
+    $fh->close;
+    $cur->close;
+
+    $self->commit;
+
+    return;
+}
+
+# -----------------------------------------------------------------------------
+
 =head2 Locking
 
 =head3 lockTable() - Locke Tabelle
@@ -3925,7 +4011,7 @@ ist es leicht möglich, eine Anwendung auf verschiedenen Schemata
 der gleichen Datenbank laufen zu lassen. Dies ist vor allem
 bei Oracle nützlich, dessen Instanzen einen großen Overhead haben.
 
-Bei SQLite die Semantik eine leicht andere: Hier ist es nicht
+Bei SQLite ist die Semantik eine leicht andere: Hier ist es nicht
 das Default-Schema, sondern es darf der Schema-Präfix
 SCHEMA verwendet werden.
 
@@ -4010,7 +4096,7 @@ Beispiel: Eine DBI MySQL-Handle $dbh wird als Lowlevel-Handle verwendet,
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
@@ -4018,7 +4104,7 @@ Frank Seitz, L<http://fseitz.de/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016 Frank Seitz
+Copyright (C) 2017 Frank Seitz
 
 =head1 LICENSE
 
