@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 use Prty::Object;
 use Time::HiRes ();
@@ -513,12 +513,12 @@ sub saveToFile {
 =head4 Description
 
 Analysiere den Tabelleninhalt und liefere eine Liste von
-Kolumnenformat-Objekten zurück. Diese können zur
-tabellarischen Formatierung der Kolumnenwerte herangezogen werden.
+Kolumnenformat-Objekten zurück. Diese können zur tabellarischen
+Formatierung der Kolumnenwerte herangezogen werden.
 
-Die Analyse wird nur einmal durchgeführt und resultierende Liste im
-Tabellenobjekt gespeichert. Ist der Parameter $force angegeben
-und "wahr", wird eine Neuberechnung forciert.
+Die Analyse wird nur einmal durchgeführt und die resultierende
+Liste im Tabellenobjekt gespeichert. Ist der Parameter $force
+angegeben und "wahr", wird eine Neuberechnung forciert.
 
 =cut
 
@@ -782,7 +782,7 @@ sub asString {
 
 =head4 Synopsis
 
-    $str = $tab->asTable;
+    $str = $tab->asTable(@opts);
 
 =head4 Description
 
@@ -794,20 +794,28 @@ Liefere eine einfache Tabellen-Repräsentation der Tabellendaten.
 
 sub asTable {
     my $self = shift;
+    # @_: @opts
+
+    # Optionen
+
+    Prty::Option->extract(\@_,
+    );
 
     my @fmt = $self->formats;
 
     my $str = '';
     for my $row ($self->rows) {
         my @arr = $row->asArray;
+        $str .= '| ';
         for (my $i = 0; $i < @arr; $i++) {
             if ($i) {
-                $str .= '|';
+                $str .= ' | ';
             }
             $str .= $fmt[$i]->asFixedWidthString($arr[$i]);
         }
-        $str =~ s/\s+$//; # Whitespace am Ende entfernen
-        $str .= "\n";
+        # $str =~ s/\s+$//; # Whitespace am Ende entfernen
+        # $str .= "\n";
+        $str .= " |\n";
     }
 
     return $str;
@@ -888,7 +896,7 @@ sub diffReport {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
