@@ -4,7 +4,10 @@ use base qw/Prty::Object/;
 use strict;
 use warnings;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
+
+use Prty::Option;
+use Prty::Math;
 
 # -----------------------------------------------------------------------------
 
@@ -141,6 +144,112 @@ sub asString {
 
 # -----------------------------------------------------------------------------
 
+=head3 asShortString() - Dauer als kürzestmögliche Zeichenkette
+
+=head4 Synopsis
+
+    $str = $dur->asShortString(@opt);
+
+=head4 Description
+
+Liefere die Zeitdauer als Zeichenkette der Form DdHhMmSs (per
+Default, siehe Option -maxUnit), wobei alle Anteile, die 0 sind,
+weggelassen werden, sowohl am Anfang als auch am Ende.
+
+=head4 Options
+
+=over 4
+
+=item -maxUnit => 'd'|'h'|'m'|'s' (Default: 'd')
+
+Größte dargestellte Einheit.
+
+=item -minUnit => 'd'|'h'|'m'|'s' (Default: 's')
+
+Kleinste dargestellte Einheit.
+
+=item -notBlank => $bool (Default: 0)
+
+Bei einer Zeit von 0 Sekunden wird ein Leerstring geliefert.
+Ist diese Option gesetzt, erfolgt immer eine Ausgabe -
+mit -minUnit als Einheit.
+
+=item -precision => $n (Default: 0)
+
+Anzahl der Sekunden-Nachkommastellen.
+
+=back
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub asShortString {
+    my $self = shift;
+    # @_: @opt
+
+    my $maxUnit = 'd';
+    my $minUnit = 's';
+    my $notBlank = 0;
+    my $precision = 0;
+
+    if (@_) {
+        Prty::Option->extract(\@_,
+            -maxUnit=>\$maxUnit,
+            -minUnit=>\$minUnit,
+            -notBlank=>\$notBlank,
+            -precision=>\$precision,
+        );
+    }
+
+    my @unit = qw/d h m s/;
+    my @arr = $self->asArray;
+
+    if ($maxUnit =~ /^[hms]$/ && $arr[0]) {
+        $arr[1] += $arr[0]*24;
+        $arr[0] = 0;
+    }
+    if ($maxUnit =~ /^[ms]$/ && $arr[1]) {
+        $arr[2] += $arr[1]*60;
+        $arr[1] = 0;
+    }
+    if ($maxUnit eq 's' && $arr[2]) {
+        $arr[3] += $arr[2]*60;
+        $arr[2] = 0;
+    }
+
+    if ($minUnit =~ /^[dhm]$/ && $arr[3]) {
+        $arr[2] += Prty::Math->roundToInt($arr[3]/60);
+        $arr[3] = 0;
+    }
+    if ($minUnit =~ /^[dh]$/ && $arr[2]) {
+        $arr[1] += Prty::Math->roundToInt($arr[2]/60);
+        $arr[2] = 0;
+    }
+    if ($minUnit eq 'd' && $arr[1]) {
+        $arr[0] += Prty::Math->roundToInt($arr[1]/24);
+        $arr[1] = 0;
+    }
+
+    if ($precision) {
+        $arr[3] = sprintf '%.*f',$precision,$arr[3];
+    }
+
+    my $str = '';
+    for my $i (0 .. 3) {
+        if ($arr[$i] != 0) {
+            $str .= $arr[$i].$unit[$i];
+        }
+    }
+    if ($str eq '' && $notBlank) {
+        $str = "0$minUnit";
+    }
+
+    return $str;
+}
+
+# -----------------------------------------------------------------------------
+
 =head3 asArray() - Dauer als Array
 
 =head4 Synopsis
@@ -366,7 +475,7 @@ sub secondsToString {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
@@ -374,7 +483,7 @@ Frank Seitz, L<http://fseitz.de/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016 Frank Seitz
+Copyright (C) 2017 Frank Seitz
 
 =head1 LICENSE
 
