@@ -4,7 +4,7 @@ use base qw/Prty::Html::Table::Base/;
 use strict;
 use warnings;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 use Prty::Html::Tag;
 
@@ -239,6 +239,12 @@ sub html {
     my $i = 0;
     for my $row (@$rowA) {
         my ($trA,@tds) = $rowCallback->($row,$i++,@$rowCallbackArgumentA);
+        if (!@tds) {
+            # Werden keine Kolumnen geliefert, erzeugen wir keine
+            # Tabellenzeile. Auf diese Weise kann in der Callback-Methode
+            # gefiltert werden.
+            next;
+        }
         my $tds;
         my $j = 0;
         for my $tdA (@tds) {
@@ -276,7 +282,7 @@ sub html {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
@@ -284,7 +290,7 @@ Frank Seitz, L<http://fseitz.de/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016 Frank Seitz
+Copyright (C) 2017 Frank Seitz
 
 =head1 LICENSE
 
