@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 # -----------------------------------------------------------------------------
 
@@ -105,6 +105,11 @@ Klasse:
 
 tr-Angabe C<'my-title'> ist äquivalent zu C<< class=>'my-title' >>
 
+=item *
+
+mit -tag=>'th' wird aus einer beliebigen Zelle eine Head-Zelle
+gemacht.
+
 =back
 
 Aussehen:
@@ -274,7 +279,7 @@ sub html {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
@@ -282,7 +287,7 @@ Frank Seitz, L<http://fseitz.de/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016 Frank Seitz
+Copyright (C) 2017 Frank Seitz
 
 =head1 LICENSE
 
