@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 use Prty::Template;
 use Prty::String;
@@ -1094,6 +1094,19 @@ ob es sich um HTML-, CSS- oder JavaScript-Content handelt.
 
 Entferne Leerzeilen aus dem Content.
 
+=item -tag => $tag (Default: erstes Argument des Methodenaufrufs)
+
+Mit dieser Option kann der Tag verändert werden. Anwendungsfall:
+statt eigentlich beim Aufruf angegebenen td soll ein th-Tag
+gesetzt werden. Beispiel:
+
+    $h->tag('td',
+        -tag=>'th',
+        ...
+    );
+
+Siehe: Prty::Html::Table::Simple
+
 =item -tagWrap => $n (Default: 0)
 
 Brich eine Tag-Zeile um, wenn sie $n Zeichen überschreitet. Wenn 0,
@@ -1286,6 +1299,12 @@ sub tag {
             elsif ($key eq '-placeholders') {
                 $placeholders = $val;
             }
+            elsif ($key eq '-tag') {
+                if (defined($val) && $val ne '') {
+                    $tag = $val;
+                    $tagStr = $uppercase? uc $tag: $tag;
+                }
+            }
             else {
                 $self->throw(
                     q{HTML-00001: Unbekannte Option},
@@ -2078,7 +2097,7 @@ sub import {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
@@ -2086,7 +2105,7 @@ Frank Seitz, L<http://fseitz.de/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016 Frank Seitz
+Copyright (C) 2017 Frank Seitz
 
 =head1 LICENSE
 
