@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 use Prty::Option;
 use Prty::FileHandle;
@@ -146,6 +146,10 @@ Kopiere Datei $srcPath nach $destPath.
 
 =over 4
 
+=item -createDir => $bool (Default: 0)
+
+Erzeuge Zielverzeichnis, falls es nicht existiert.
+
 =item -preserve => $bool (Default: 0)
 
 Behalte den Zeitpunkt der letzten Änderung bei.
@@ -164,16 +168,23 @@ sub copy {
 
     # Optionen
 
+    my $createDir = 0;
     my $preserve = 0;
 
     if (@_) {
         Prty::Option->extract(\@_,
+            -createDir=>\$createDir,
             -preserve=>\$preserve,
         );
     }
 
     # Operation ausführen
 
+    if ($createDir) {
+        my ($destDir) = $class->split($destPath);
+        $class->mkdir($destDir,-recursive=>1);
+    }
+
     my $fh1 = Prty::FileHandle->new('<',$srcPath);
     my $fh2 = Prty::FileHandle->new('>',$destPath);
     while (<$fh1>) {
@@ -1706,7 +1717,7 @@ sub symlinkRelative {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
@@ -1714,7 +1725,7 @@ Frank Seitz, L<http://fseitz.de/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016 Frank Seitz
+Copyright (C) 2017 Frank Seitz
 
 =head1 LICENSE
 
