@@ -4,7 +4,7 @@ use base qw/Prty::Object/;
 use strict;
 use warnings;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 use Prty::Option;
 use File::Rsync ();
@@ -38,10 +38,10 @@ L<Prty::Object>
 
 =head1 DESCRIPTION
 
-Führe ein rsync-Kommando unter Kontrolle von Perl aus. Die Klasse
-stützt sich auf die Klasse File::Rsync ab und stellt gegenüber dieser
-eine spezialisierte, einfachere Schnittstelle zur Verfügung,
-die nach Bedarf erweitert wird. Eigenschaften:
+Führe rsync(1) unter Kontrolle von Perl aus. Die Klasse stützt sich
+auf die Klasse File::Rsync ab und stellt gegenüber dieser eine
+spezialisierte, einfachere Schnittstelle zur Verfügung.
+Eigenschaften:
 
 =over 2
 
@@ -57,7 +57,7 @@ im Fehlerfall wird eine Exception geworfen
 =item *
 
 eine Ausgabe findet nur im Fehlerfall und bei Änderungen statt,
-die statistische Ausgabe unterbleibt
+die statistische Ausgabe von rsync unterbleibt
 
 =back
 
@@ -73,7 +73,7 @@ die statistische Ausgabe unterbleibt
 
 =head4 Description
 
-Führe ein rsync-Kommando für Quellpfad $src und Zielpfad $dest aus.
+Führe rsync(1) für Quellpfad $src und Zielpfad $dest aus.
 Ohne Angabe von Optionen wird als Kommandozeile ausgeführt:
 
     rsync --archive --verbose --delete SRC DEST
@@ -202,7 +202,7 @@ sub exec {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
