@@ -5,12 +5,12 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.101;
+our $VERSION = 1.102;
 
 use Encode::Guess ();
 use Encode ();
-use Prty::Array;
 use Prty::Option;
+use Prty::Array;
 
 # -----------------------------------------------------------------------------
 
@@ -96,6 +96,102 @@ sub autoDecode {
 
 =head2 Einrückung
 
+=head3 indent() - Rücke Text ein
+
+=head4 Synopsis
+
+    $str2 = $class->indent($str,$indentStr,@opt);
+    $class->indent(\$str,$indentStr,@opt);
+
+=head4 Description
+
+Rücke den Text $str um Zeichenkette $indentStr ein und liefere
+das Resultat zurück.
+
+Die Einrück-Zeichenkette $indentStr wird jeder Zeile von $str
+hinzugefügt, außer Leerzeilen.
+
+=head4 Options
+
+=over 4
+
+=item -indentBlankLines => $bool (Default: 0)
+
+Rücke auch Leerzeilen ein. Per Default werden nur Zeilen mit
+wenigstens einem Zeichen eingerückt.
+
+Diese Option ist nützlich, wenn die Funktion zum Auskommentieren
+genutzt werden soll.
+
+=item -strip => $bool (Default: 0)
+
+Entferne Newlines am Anfang und Whitespace am Ende. Per Default
+geschieht dies nicht.
+
+=back
+
+=head4 Example
+
+=over 2
+
+=item *
+
+Texteinrückung um vier Leerzeichen
+
+    $class->indent($txt,' ' x 4);
+    
+    |Dies ist                   |    Dies ist
+    |ein Test-   - wird zu ->   |    ein Test-
+    |Text.                      |    Text.
+
+=back
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub indent {
+    my $class = shift;
+    my $str = shift;
+    my $indentStr = shift;
+    # @_: @opt
+
+    # Optionen
+
+    my $indentBlankLines = 0;
+    my $strip = 0;
+    if (@_) {
+        Prty::Option->extract(\@_,
+            -indentBlankLines=>\$indentBlankLines,
+            -strip=>\$strip,
+        );
+    }
+
+    # Verarbeiten
+
+    my $ref = ref $str? $str: \$str;
+
+    if ($strip) {
+        $$ref =~ s/^\n+//; # Newlines am Anfang entfernen
+        $$ref =~ s/\s+$//; # Whitespace am Ende entfernen
+    }
+
+    if (defined $indentStr) {
+        if ($indentBlankLines) {
+            # alle Zeilen einrücken
+            $$ref =~ s/^/$indentStr/mg;
+        }
+        else {
+            # Leerzeilen nicht einrücken
+            $$ref =~ s/^(.)/$indentStr$1/mg;
+        }
+    }
+
+    return $str unless ref $str;
+}
+
+# -----------------------------------------------------------------------------
+
 =head3 determineIndentation() - Einrücktiefe eines Textes
 
 =head4 Synopsis
@@ -501,7 +597,7 @@ sub removeComments {
 
 =head1 VERSION
 
-1.101
+1.102
 
 =head1 AUTHOR
 
